@@ -1,20 +1,18 @@
 package SVN::Class::Info;
 use strict;
 use warnings;
-use base qw( Rose::Object );
-use Rose::Object::MakeMethods::Generic (
-    scalar => [
-        qw( path name _url root rev
-            node schedule author last_rev date
-            updated checksum uuid
-            )
-    ]
+use base qw( Class::Accessor::Fast );
+__PACKAGE__->mk_accessors(
+    qw( path name _url root uid rev
+        node schedule author last_rev date
+        updated checksum
+        )
 );
 use Carp;
 use Data::Dump;
 use SVN::Class::Repos;
 
-our $VERSION = '0.13_03';
+our $VERSION = '0.07';
 
 =head1 NAME
 
@@ -56,7 +54,8 @@ sub new {
     if ( !$buf or !ref($buf) or ref($buf) ne 'ARRAY' ) {
         croak "need array ref of 'svn info' output";
     }
-    return $class->SUPER::new( _make_hash(@$buf) );
+    my $hashref = _make_hashref(@$buf);
+    return $class->SUPER::new($hashref);
 }
 
 =head2 dump
@@ -85,7 +84,7 @@ my %fieldmap = (
     'Checksum'            => 'checksum'
 );
 
-sub _make_hash {
+sub _make_hashref {
     my %hash;
     for (@_) {
         my ( $field, $value ) = (m/^([^:]+):\ (.+)$/);
@@ -94,7 +93,7 @@ sub _make_hash {
         }
         $hash{ $fieldmap{$field} } = $value;
     }
-    return %hash;
+    return \%hash;
 }
 
 =head2 url
@@ -108,34 +107,6 @@ sub url {
     return SVN::Class::Repos->new( $self->_url );
 }
 
-=head2 path 
-
-=head2 name 
-
-=head2 root 
-
-=head2 rev
-
-=head2 node 
-
-=head2 schedule 
-
-=head2 author 
-
-=head2 last_rev 
-
-=head2 date
-
-=head2 updated 
-
-=head2 checksum 
-
-=head2 uuid
-
-Get/set the info params. These are really only useful as accessors (getters).
-
-=cut
-
 1;
 
 __END__
@@ -192,6 +163,7 @@ sponsored the development of this software.
 =head1 COPYRIGHT
 
 Copyright 2008 by the Regents of the University of Minnesota.
+All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
